#ifndef SETTINGSWINDOW_H
#define SETTINGSWINDOW_H

#include <QMainWindow>
#include <QSettings>
class MaemoBarcodeWindow;
namespace Ui {
    class SettingsWindow;
}

class SettingsWindow : public QMainWindow {
    Q_OBJECT
public:
    SettingsWindow(MaemoBarcodeWindow *parent = 0);
    ~SettingsWindow();
protected:
    void changeEvent(QEvent *e);
    void hideEvent(QHideEvent *);
    void showEvent(QShowEvent *);
private:
    QSettings *settings;
    Ui::SettingsWindow *ui;
    MaemoBarcodeWindow *parent;

private slots:
    void on_spnAutoFocusDelay_valueChanged(double );
    void on_chkSaveHistory_clicked();
};

#endif // SETTINGSWINDOW_H
